==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/lb.pl <==
{
  am_pm_abbreviated => [
    "moies",
    "nom\N{U+00eb}ttes"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH 'Auer'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "lb",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+00e9}i.",
    "D\N{U+00eb}n.",
    "M\N{U+00eb}t.",
    "Don.",
    "Fre.",
    "Sam.",
    "Son."
  ],
  day_format_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S"
  ],
  day_format_wide => [
    "M\N{U+00e9}indeg",
    "D\N{U+00eb}nschdeg",
    "M\N{U+00eb}ttwoch",
    "Donneschdeg",
    "Freideg",
    "Samschdeg",
    "Sonndeg"
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+00e9}i",
    "D\N{U+00eb}n",
    "M\N{U+00eb}t",
    "Don",
    "Fre",
    "Sam",
    "Son"
  ],
  day_stand_alone_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S"
  ],
  day_stand_alone_wide => [
    "M\N{U+00e9}indeg",
    "D\N{U+00eb}nschdeg",
    "M\N{U+00eb}ttwoch",
    "Donneschdeg",
    "Freideg",
    "Samschdeg",
    "Sonndeg"
  ],
  era_abbreviated => [
    "v. Chr.",
    "n. Chr."
  ],
  era_narrow => [
    "v. Chr.",
    "n. Chr."
  ],
  era_wide => [
    "v. Chr.",
    "n. Chr."
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Luxembourgish",
  month_format_abbreviated => [
    "Jan.",
    "Feb.",
    "M\N{U+00e4}e.",
    "Abr.",
    "Mee",
    "Juni",
    "Juli",
    "Aug.",
    "Sep.",
    "Okt.",
    "Nov.",
    "Dez."
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}erz",
    "Abr\N{U+00eb}ll",
    "Mee",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}e",
    "Abr",
    "Mee",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}erz",
    "Abr\N{U+00eb}ll",
    "Mee",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember"
  ],
  name => "Luxembourgish",
  native_language => "L\N{U+00eb}tzebuergesch",
  native_name => "L\N{U+00eb}tzebuergesch",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/lb.pl <==
{
  am_pm_abbreviated => [
    "moies",
    "nom\N{U+00eb}ttes",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E, HH:mm",
    EHms => "E, HH:mm:ss",
    Ed => "E, d.",
    Ehm => "E, h:mm a",
    Ehms => "E, h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH 'Auer'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E, d. MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M.y",
    yMEd => "E, d.M.y",
    yMMM => "MMM y",
    yMMMEd => "E, d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "lb",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "d. MMM y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "M\N{U+00e9}i.",
    "D\N{U+00eb}n.",
    "M\N{U+00eb}t.",
    "Don.",
    "Fre.",
    "Sam.",
    "Son.",
  ],
  day_format_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "M\N{U+00e9}indeg",
    "D\N{U+00eb}nschdeg",
    "M\N{U+00eb}ttwoch",
    "Donneschdeg",
    "Freideg",
    "Samschdeg",
    "Sonndeg",
  ],
  day_stand_alone_abbreviated => [
    "M\N{U+00e9}i",
    "D\N{U+00eb}n",
    "M\N{U+00eb}t",
    "Don",
    "Fre",
    "Sam",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "D",
    "M",
    "D",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "M\N{U+00e9}indeg",
    "D\N{U+00eb}nschdeg",
    "M\N{U+00eb}ttwoch",
    "Donneschdeg",
    "Freideg",
    "Samschdeg",
    "Sonndeg",
  ],
  era_abbreviated => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_narrow => [
    "v. Chr.",
    "n. Chr.",
  ],
  era_wide => [
    "v. Chr.",
    "n. Chr.",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Luxembourgish",
  month_format_abbreviated => [
    "Jan.",
    "Feb.",
    "M\N{U+00e4}e.",
    "Abr.",
    "Mee",
    "Juni",
    "Juli",
    "Aug.",
    "Sep.",
    "Okt.",
    "Nov.",
    "Dez.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}erz",
    "Abr\N{U+00eb}ll",
    "Mee",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "M\N{U+00e4}e",
    "Abr",
    "Mee",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Dez",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januar",
    "Februar",
    "M\N{U+00e4}erz",
    "Abr\N{U+00eb}ll",
    "Mee",
    "Juni",
    "Juli",
    "August",
    "September",
    "Oktober",
    "November",
    "Dezember",
  ],
  name => "Luxembourgish",
  native_language => "L\N{U+00eb}tzebuergesch",
  native_name => "L\N{U+00eb}tzebuergesch",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. Quartal",
    "2. Quartal",
    "3. Quartal",
    "4. Quartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}
